@@ -9,7 +9,7 @@
 
 namespace cryfs {
 
-class CrySymlink final: public fspp::Symlink, CryNode {
+class CrySymlink final: public fspp::Symlink, public CryNode {
 public:
   CrySymlink(CryDevice *device, cpputils::unique_ref<parallelaccessfsblobstore::DirBlobRef> parent, boost::optional<cpputils::unique_ref<parallelaccessfsblobstore::DirBlobRef>> grandparent, const blockstore::Key &key);
   ~CrySymlink();
