@@ -3,7 +3,7 @@
 #define MESSMER_FSPP_FUSE_PARAMS_H_
 
 #define FUSE_USE_VERSION 26
-#ifdef __linux__
+#if defined(__linux__) || defined(__FreeBSD__)
 #include <fuse.h>
 #elif __APPLE__
 #include <osxfuse/fuse.h>
